package me.springframework.gwtsample.client.beanfactory;

/**
 * An object factory, providing access to a network of wired objects, 
 * some of them lazily instantiated. You can refer to some objects by 
 * name. The named objects managed by this class are:
 *
 * <ul>
 * <li>testBean : {@link java.lang.String}</li>
 * <li>resultView : {@link me.springframework.gwtsample.client.act.ResultView}</li>
 * <li>addressSelectionView : {@link me.springframework.gwtsample.client.act.AddressSelectionView}</li>
 * <li>mapView : {@link me.springframework.gwtsample.client.act.MapView}</li>
 * <li>addressSelectionActivity : {@link me.springframework.gwtsample.client.act.AddressSelectionActivity}</li>
 * <li>mainView : {@link me.springframework.gwtsample.client.act.MainView}</li>
 * <li>resultStateHolder : {@link me.springframework.gwtsample.client.util.Holder}</li>
 * <li>resultActivity : {@link me.springframework.gwtsample.client.act.ResultActivity}</li>
 * <li>addressInputView : {@link me.springframework.gwtsample.client.act.AddressInputView}</li>
 * <li>mainStateHolder : {@link me.springframework.gwtsample.client.util.Holder}</li>
 * <li>addressInputActivity : {@link me.springframework.gwtsample.client.act.AddressInputActivity}</li>
 * <li>descriptionView : {@link me.springframework.gwtsample.client.act.DescriptionView}</li>
 * <li>addressStateHolder : {@link me.springframework.gwtsample.client.util.Holder}</li> 
 * </ul>
 * 
 */
public class PolokoBeanFactory  {

    /**
     * A cached reference to the bean named "testBean".
     */
    private java.lang.String testBean;

    /**
     * A cached reference to the bean named "resultView".
     */
    private me.springframework.gwtsample.client.act.ResultView resultView;

    /**
     * A cached reference to the bean named "addressSelectionView".
     */
    private me.springframework.gwtsample.client.act.AddressSelectionView addressSelectionView;

    /**
     * A cached reference to the bean named "mapView".
     */
    private me.springframework.gwtsample.client.act.MapView mapView;

    /**
     * A cached reference to the bean named "addressSelectionActivity".
     */
    private me.springframework.gwtsample.client.act.AddressSelectionActivity addressSelectionActivity;

    /**
     * A cached reference to the bean named "mainView".
     */
    private me.springframework.gwtsample.client.act.MainView mainView;

    /**
     * A cached reference to the bean named "resultStateHolder".
     */
    private me.springframework.gwtsample.client.util.Holder resultStateHolder;

    /**
     * A cached reference to the bean named "resultActivity".
     */
    private me.springframework.gwtsample.client.act.ResultActivity resultActivity;

    /**
     * A cached reference to the bean named "addressInputView".
     */
    private me.springframework.gwtsample.client.act.AddressInputView addressInputView;

    /**
     * A cached reference to the bean named "mainStateHolder".
     */
    private me.springframework.gwtsample.client.util.Holder mainStateHolder;

    /**
     * A cached reference to the bean named "addressInputActivity".
     */
    private me.springframework.gwtsample.client.act.AddressInputActivity addressInputActivity;

    /**
     * A cached reference to the bean named "descriptionView".
     */
    private me.springframework.gwtsample.client.act.DescriptionView descriptionView;

    /**
     * A cached reference to the bean named "addressStateHolder".
     */
    private me.springframework.gwtsample.client.util.Holder addressStateHolder;
  
    /**
     * Constructs an instance of this bean factory.
     */
    public PolokoBeanFactory() {
        start();
    }
  
    /**
     * Returns an object by looking it up by its name.
     *
     * @return The object with the given name, constructed by the PolokoBeanFactory.
     * @see PolokoBeanFactory
     * @throws java.lang.RuntimeException In case of problems creating the bean.
     */
    public synchronized Object getBean(String name) throws java.lang.RuntimeException {
        if ("testBean".equals(name)) return getTestBean();
        if ("resultView".equals(name)) return getResultView();
        if ("addressSelectionView".equals(name)) return getAddressSelectionView();
        if ("mapView".equals(name)) return getMapView();
        if ("addressSelectionActivity".equals(name)) return getAddressSelectionActivity();
        if ("mainView".equals(name)) return getMainView();
        if ("resultStateHolder".equals(name)) return getResultStateHolder();
        if ("resultActivity".equals(name)) return getResultActivity();
        if ("addressInputView".equals(name)) return getAddressInputView();
        if ("mainStateHolder".equals(name)) return getMainStateHolder();
        if ("addressInputActivity".equals(name)) return getAddressInputActivity();
        if ("descriptionView".equals(name)) return getDescriptionView();
        if ("addressStateHolder".equals(name)) return getAddressStateHolder();
        return null; // Keep the compiler happy
    }

    /**
     * Creates bean testBean.
     */
    private final java.lang.String getTestBean() {
        if (testBean == null) {
            try {
                testBean = new java.lang.String("Hello GWT Spring ME");

                // No init method 
            } catch(Exception e) {
                throw new java.lang.RuntimeException(e.getMessage());
            }
        }    
        return testBean;
    }

    /**
     * Creates bean resultView.
     */
    private final me.springframework.gwtsample.client.act.ResultView getResultView() {
        if (resultView == null) {
            try {
                resultView = new me.springframework.gwtsample.client.act.ResultView();
                resultView.setResultStateHolder(getResultStateHolder());
                resultView.init(); 
            } catch(Exception e) {
                throw new java.lang.RuntimeException(e.getMessage());
            }
        }    
        return resultView;
    }

    /**
     * Creates bean addressSelectionView.
     */
    private final me.springframework.gwtsample.client.act.AddressSelectionView getAddressSelectionView() {
        if (addressSelectionView == null) {
            try {
                addressSelectionView = new me.springframework.gwtsample.client.act.AddressSelectionView();
                addressSelectionView.setAddressStateHolder(getAddressStateHolder());
                addressSelectionView.setAddressSelectionActivity(getAddressSelectionActivity());
                addressSelectionView.init(); 
            } catch(Exception e) {
                throw new java.lang.RuntimeException(e.getMessage());
            }
        }    
        return addressSelectionView;
    }

    /**
     * Creates bean mapView.
     */
    private final me.springframework.gwtsample.client.act.MapView getMapView() {
        if (mapView == null) {
            try {
                mapView = new me.springframework.gwtsample.client.act.MapView();
                mapView.setAddressStateHolder(getAddressStateHolder());
                mapView.init(); 
            } catch(Exception e) {
                throw new java.lang.RuntimeException(e.getMessage());
            }
        }    
        return mapView;
    }

    /**
     * Creates bean addressSelectionActivity.
     */
    private final me.springframework.gwtsample.client.act.AddressSelectionActivity getAddressSelectionActivity() {
        if (addressSelectionActivity == null) {
            try {
                addressSelectionActivity = new me.springframework.gwtsample.client.act.AddressSelectionActivity();
                addressSelectionActivity.setResultActivity(getResultActivity());
                addressSelectionActivity.setResultStateHolder(getResultStateHolder());
                addressSelectionActivity.setAddressInputActivity(getAddressInputActivity());
                addressSelectionActivity.setMainStateHolder(getMainStateHolder());
                addressSelectionActivity.setAddressStateHolder(getAddressStateHolder());
                // No init method 
            } catch(Exception e) {
                throw new java.lang.RuntimeException(e.getMessage());
            }
        }    
        return addressSelectionActivity;
    }

    /**
     * Creates bean mainView.
     */
    private final me.springframework.gwtsample.client.act.MainView getMainView() {
        if (mainView == null) {
            try {
                mainView = new me.springframework.gwtsample.client.act.MainView();
                mainView.setSelectionWidget(getAddressSelectionView());
                mainView.setDescritpionWidget(getDescriptionView());
                mainView.setInputWidget(getAddressInputView());
                mainView.setResultWidget(getResultView());
                mainView.setMapWidget(getMapView());
                mainView.setMainStateHolder(getMainStateHolder());
                mainView.init(); 
            } catch(Exception e) {
                throw new java.lang.RuntimeException(e.getMessage());
            }
        }    
        return mainView;
    }

    /**
     * Creates bean resultStateHolder.
     */
    private final me.springframework.gwtsample.client.util.Holder getResultStateHolder() {
        if (resultStateHolder == null) {
            try {
                resultStateHolder = new me.springframework.gwtsample.client.util.Holder(createSource88());

                // No init method 
            } catch(Exception e) {
                throw new java.lang.RuntimeException(e.getMessage());
            }
        }    
        return resultStateHolder;
    }

    /**
     * Creates bean resultActivity.
     */
    private final me.springframework.gwtsample.client.act.ResultActivity getResultActivity() {
        if (resultActivity == null) {
            try {
                resultActivity = new me.springframework.gwtsample.client.act.ResultActivity();
                resultActivity.setAddressInputActivity(getAddressInputActivity());
                resultActivity.setMainStateHolder(getMainStateHolder());
                resultActivity.setResultStateHolder(getResultStateHolder());
                // No init method 
            } catch(Exception e) {
                throw new java.lang.RuntimeException(e.getMessage());
            }
        }    
        return resultActivity;
    }

    /**
     * Creates bean addressInputView.
     */
    private final me.springframework.gwtsample.client.act.AddressInputView getAddressInputView() {
        if (addressInputView == null) {
            try {
                addressInputView = new me.springframework.gwtsample.client.act.AddressInputView();
                addressInputView.setAddressInputActivity(getAddressInputActivity());
                addressInputView.setAddressStateHolder(getAddressStateHolder());
                addressInputView.init(); 
            } catch(Exception e) {
                throw new java.lang.RuntimeException(e.getMessage());
            }
        }    
        return addressInputView;
    }

    /**
     * Creates bean mainStateHolder.
     */
    private final me.springframework.gwtsample.client.util.Holder getMainStateHolder() {
        if (mainStateHolder == null) {
            try {
                mainStateHolder = new me.springframework.gwtsample.client.util.Holder(createSource85());

                // No init method 
            } catch(Exception e) {
                throw new java.lang.RuntimeException(e.getMessage());
            }
        }    
        return mainStateHolder;
    }

    /**
     * Creates bean addressInputActivity.
     */
    private final me.springframework.gwtsample.client.act.AddressInputActivity getAddressInputActivity() {
        if (addressInputActivity == null) {
            try {
                addressInputActivity = new me.springframework.gwtsample.client.act.AddressInputActivity();
                addressInputActivity.setAddressStateHolder(getAddressStateHolder());
                addressInputActivity.setAddressSelectionActivity(getAddressSelectionActivity());
                addressInputActivity.setMainStateHolder(getMainStateHolder());
                // No init method 
            } catch(Exception e) {
                throw new java.lang.RuntimeException(e.getMessage());
            }
        }    
        return addressInputActivity;
    }

    /**
     * Creates bean descriptionView.
     */
    private final me.springframework.gwtsample.client.act.DescriptionView getDescriptionView() {
        if (descriptionView == null) {
            try {
                descriptionView = new me.springframework.gwtsample.client.act.DescriptionView();
                descriptionView.setResultActivity(getResultActivity());
                descriptionView.init(); 
            } catch(Exception e) {
                throw new java.lang.RuntimeException(e.getMessage());
            }
        }    
        return descriptionView;
    }

    /**
     * Creates bean addressStateHolder.
     */
    private final me.springframework.gwtsample.client.util.Holder getAddressStateHolder() {
        if (addressStateHolder == null) {
            try {
                addressStateHolder = new me.springframework.gwtsample.client.util.Holder(createSource82());

                // No init method 
            } catch(Exception e) {
                throw new java.lang.RuntimeException(e.getMessage());
            }
        }    
        return addressStateHolder;
    }


    /**
     * Creates a bean of type me.springframework.gwtsample.client.state.ResultState, injected into a constructor argument of bean resultStateHolder. 
     * 
     * @return One of the required instances of {@link me.springframework.gwtsample.client.state.ResultState}.
     */
    private final me.springframework.gwtsample.client.state.ResultState createSource88() {
        try {
            me.springframework.gwtsample.client.state.ResultState result = new me.springframework.gwtsample.client.state.ResultState();
            return result;
        } catch(Exception e) {
            throw new java.lang.RuntimeException(e.getMessage());
        }
    }

    /**
     * Creates a bean of type me.springframework.gwtsample.client.state.MainState, injected into a constructor argument of bean mainStateHolder. 
     * 
     * @return One of the required instances of {@link me.springframework.gwtsample.client.state.MainState}.
     */
    private final me.springframework.gwtsample.client.state.MainState createSource85() {
        try {
            me.springframework.gwtsample.client.state.MainState result = new me.springframework.gwtsample.client.state.MainState();
            return result;
        } catch(Exception e) {
            throw new java.lang.RuntimeException(e.getMessage());
        }
    }

    /**
     * Creates a bean of type me.springframework.gwtsample.client.state.AddressState, injected into a constructor argument of bean addressStateHolder. 
     * 
     * @return One of the required instances of {@link me.springframework.gwtsample.client.state.AddressState}.
     */
    private final me.springframework.gwtsample.client.state.AddressState createSource82() {
        try {
            me.springframework.gwtsample.client.state.AddressState result = new me.springframework.gwtsample.client.state.AddressState();
            return result;
        } catch(Exception e) {
            throw new java.lang.RuntimeException(e.getMessage());
        }
    }

    /**
     * "Starts" the PolokoBeanFactory; instances that have been 
     * configured to be loaded eagerly will be loaded, and their init-methods
     * will be called. 
     */
    private final void start() {
        // Skipping testBean
        // Skipping resultView
        // Skipping addressSelectionView
        // Skipping mapView
        // Skipping addressSelectionActivity
        // Skipping mainView
        // Skipping resultStateHolder
        // Skipping resultActivity
        // Skipping addressInputView
        // Skipping mainStateHolder
        // Skipping addressInputActivity
        // Skipping descriptionView
        // Skipping addressStateHolder
    }
    
    /**
     * "Stops" the PolokoBeanFactory; instances that have an 
     * destroy-method defined will get that method invoked.
     */
    public final void stop() {
        // Skipping testBean
        // Skipping resultView
        // Skipping addressSelectionView
        // Skipping mapView
        // Skipping addressSelectionActivity
        // Skipping mainView
        // Skipping resultStateHolder
        // Skipping resultActivity
        // Skipping addressInputView
        // Skipping mainStateHolder
        // Skipping addressInputActivity
        // Skipping descriptionView
        // Skipping addressStateHolder
    }
    
    	    
}